Wingdings - Wikipedia

# Wingdings

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search
Fonts for dingbats (decorational glyphs and symbols)

Wingdings series
Language(s) | Dingbat ornaments
Definitions | UTC L2/12-368
Classification | Pi fonts
Other related encoding(s) | Webdings, Zapf Dingbats, Bookshelf Symbol 7

Wingdings is a series of dingbat fonts that render letters as a variety of symbols. They were originally developed in 1990 by Microsoft by combining glyphs from Lucida Icons, Arrows, and Stars licensed from Charles Bigelow and Kris Holmes.[1] Certain versions of the font's copyright string include an attribution to Type Solutions, Inc., the maker of a tool used to hint the font.

None of the characters were mapped to Unicode at the time; however, Unicode approved the addition of many symbols in the Wingdings and Webdings fonts in Unicode 7.0.[2][3]

## Wingdings[edit]

Wingdings
Category | Symbol
Designer(s) | Charles Bigelow Kris Holmes
Foundry | Bigelow and Holmes, Microsoft Corp.
Date released | 1990
Sample

Wingdings is a TrueType dingbat font included in all versions of Microsoft Windows from version 3.1[4] until Windows Vista/Server 2008, and also in a number of application packages of that era.[5]

The Wingdings trademark is owned by Microsoft,[4] and the design and glyph order was awarded U.S. Design Patent D341848 in 1993.[6][7] The patent expired in 2005. In many other countries, a Design Patent would be called a registered design. It is registration of a design to deter imitation, rather than a claim of a novel invention.

This font contains many largely recognized shapes and gestures as well as some recognized world symbols, such as the Star of David, the symbols of the zodiac, index or manicule signs, hand gestures, and obscure ampersands.

Mosaic of Wingdings characters

### Character set[edit]

Wingdings
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0_ 0 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
1_ 16 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
2_ 32 | SP 0020 | 🖉 1F589 | ✂ 2702 | ✁ 2701 | 👓︎ 1F453 | 🕭 1F56D | 🕮 1F56E | 🕯 1F56F | 🕿 1F57F | ✆ 2706 | 🖂 1F582 | 🖃 1F583 | 📪︎ 1F4EA | 📫︎ 1F4EB | 📬︎ 1F4EC | 📭︎ 1F4ED
3_ 48 | 🗀 1F5C0 | 🗁 1F5C1 | 🗎 1F5CE | 🗏 1F5CF | 🗐 1F5D0 | 🗄 1F5C4 | ⌛︎ 231B | 🖮 1F5AE | 🖰 1F5B0 | 🖲 1F5B2 | 🖳 1F5B3 | 🖴 1F5B4 | 🖫 1F5AB | 🖬 1F5AC | ✇ 2707 | ✍ 270D
4_ 64 | 🖎 1F58E | ✌ 270C | 🖏 1F58F | 👍︎ 1F44D | 👎︎ 1F44E | ☜ 261C | ☞ 261E | ☝ 261D | ☟ 261F | 🖐 1F590 | ☺ 263A | 😐︎ 1F610 | ☹ 2639 | 💣︎ 1F4A3 | 🕱 1F571 | 🏳 1F3F3
5_ 80 | 🏱 1F3F1 | ✈ 2708 | ☼ 263C | 🌢 1F322 | ❄ 2744 | 🕆 1F546 | ✞ 271E | 🕈 1F548 | ✠ 2720 | ✡ 2721 | ☪ 262A | ☯ 262F | 🕉 1F549 | ☸ 2638 | ♈︎ 2648 | ♉︎ 2649
6_ 96 | ♊︎ 264A | ♋︎ 264B | ♌︎ 264C | ♍︎ 264D | ♎︎ 264E | ♏︎ 264F | ♐︎ 2650 | ♑︎ 2651 | ♒︎ 2652 | ♓︎ 2653 | 🙰 1F670 | 🙵 1F675 | ⚫︎ 26AB | 🔾 1F53E | ◼ 25FC | 🞏 1F78F
7_ 112 | 🞐 1F790 | ❑ 2751 | ❒ 2752 | 🞟 1F79F | ⧫ 29EB | ◆ 25C6 | ❖ 2756 | ⬩ 2B29 | ⌧ 2327 | ⮹ 2BB9 | ⌘ 2318 | 🏵 1F3F5 | 🏶 1F3F6 | 🙶 1F676 | 🙷 1F677 | ▯ 25AF
8_ 128 | 🄋 1F10B | ➀ 2780 | ➁ 2781 | ➂ 2782 | ➃ 2783 | ➄ 2784 | ➅ 2785 | ➆ 2786 | ➇ 2787 | ➈ 2788 | ➉ 2789 | 🄌 1F10C | ➊ 278A | ➋ 278B | ➌ 278C | ➍ 278D
9_ 144 | ➎ 278E | ➏ 278F | ➐ 2790 | ➑ 2791 | ➒ 2792 | ➓ 2793 | 🙢 1F662 | 🙠 1F660 | 🙡 1F661 | 🙣 1F663 | 🙞 1F65E | 🙜 1F65C | 🙝 1F65D | 🙟 1F65F | ∙ 2219 | • 2022
A_ 160 | ⬝ 2B1D | ⭘ 2B58 | 🞆 1F786 | 🞈 1F788 | 🞊 1F78A | 🞋 1F78B | 🔿 1F53F | ▪ 25AA | 🞎 1F78E | 🟁 1F7C1 | 🟅 1F7C5 | ★ 2605 | 🟋 1F7CB | 🟏 1F7CF | 🟓 1F7D3 | 🟑 1F7D1
B_ 176 | ⯐ 2BD0 | ⌖ 2316 | ⯎ 2BCE | ⯏ 2BCF | ⯑ 2BD1 | ✪ 272A | ✰ 2730 | 🕐︎ 1F550 | 🕑︎ 1F551 | 🕒︎ 1F552 | 🕓︎ 1F553 | 🕔︎ 1F554 | 🕕︎ 1F555 | 🕖︎ 1F556 | 🕗︎ 1F557 | 🕘︎ 1F558
C_ 192 | 🕙︎ 1F559 | 🕚︎ 1F55A | 🕛︎ 1F55B | ⮰ 2BB0 | ⮱ 2BB1 | ⮲ 2BB2 | ⮳ 2BB3 | ⮴ 2BB4 | ⮵ 2BB5 | ⮶ 2BB6 | ⮷ 2BB7 | 🙪 1F66A | 🙫 1F66B | 🙕 1F655 | 🙔 1F654 | 🙗 1F657
D_ 208 | 🙖 1F656 | 🙐 1F650 | 🙑 1F651 | 🙒 1F652 | 🙓 1F653 | ⌫ 232B | ⌦ 2326 | ⮘ 2B98 | ⮚ 2B9A | ⮙ 2B99 | ⮛ 2B9B | ⮈ 2B88 | ⮊ 2B8A | ⮉ 2B89 | ⮋ 2B8B | 🡨 1F868
E_ 224 | 🡪 1F86A | 🡩 1F869 | 🡫 1F86B | 🡬 1F86C | 🡭 1F86D | 🡯 1F86F | 🡮 1F86E | 🡸 1F878 | 🡺 1F87A | 🡹 1F879 | 🡻 1F87B | 🡼 1F87C | 🡽 1F87D | 🡿 1F87F | 🡾 1F87E | ⇦ 21E6
F_ 240 | ⇨ 21E8 | ⇧ 21E7 | ⇩ 21E9 | ⬄ 2B04 | ⇳ 21F3 | ⬁ 2B01 | ⬀ 2B00 | ⬃ 2B03 | ⬂ 2B02 | 🢬 1F8AC | 🢭 1F8AD | 🗶 1F5F6 | ✓ 2713 | 🗷 1F5F7 | 🗹 1F5F9 | [a]

Letter Number Punctuation Symbol Other Undefined

1. ^ The character 255 (FF) represents the Windows icon, which as a corporate logo has no Unicode point. Similar Unicode characters include U+1FA9F 🪟︎ WINDOW. Compare the status of the Apple logo in Mac OS Roman and Mac OS Symbol.

## Wingdings 2[edit]

Wingdings
Category | Dingbat
Designer(s) | Charles Bigelow Kris Holmes
Foundry | Type Solutions
Sample

Wingdings 2 is a TrueType font distributed with a variety of Microsoft applications, including Microsoft Office up to version 2010.[5] The font was developed in 1990 by Type Solutions, Inc. The current copyright holder is Microsoft Corporation. Among the features of Wingdings 2 are 16 forms of the index, Enclosed Alphanumerics from 0 to 10, multiple forms of ampersand and interrobang, several geometric shapes and an asterism.

Mosaic of Wingdings 2 characters

### Character set[edit]

Wingdings 2
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0_ 0 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
1_ 16 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
2_ 32 | SP 0020 | 🖊 1F58A | 🖋 1F58B | 🖌 1F58C | 🖍 1F58D | ✄ 2704 | ✀ 2700 | 🕾 1F57E | 🕽 1F57D | 🗅 1F5C5 | 🗆 1F5C6 | 🗇 1F5C7 | 🗈 1F5C8 | 🗉 1F5C9 | 🗊 1F5CA | 🗋 1F5CB
3_ 48 | 🗌 1F5CC | 🗍 1F5CD | 📋︎ 1F4CB | 🗑 1F5D1 | 🗔 1F5D4 | 🖵 1F5B5 | 🖶 1F5B6 | 🖷 1F5B7 | 🖸 1F5B8 | 🖭 1F5AD | 🖯 1F5AF | 🖱 1F5B1 | 🖒 1F592 | 🖓 1F593 | 🖘 1F598 | 🖙 1F599
4_ 64 | 🖚 1F59A | 🖛 1F59B | 👈︎ 1F448 | 👉︎ 1F449 | 🖜 1F59C | 🖝 1F59D | 🖞 1F59E | 🖟 1F59F | 🖠 1F5A0 | 🖡 1F5A1 | 👆︎ 1F446 | 👇︎ 1F447 | 🖢 1F5A2 | 🖣 1F5A3 | 🖑 1F591 | 🗴 1F5F4
5_ 80 | 🗸 1F5F8 | 🗵 1F5F5 | ☑ 2611 | ⮽ 2BBD | ☒ 2612 | ⮾ 2BBE | ⮿ 2BBF | 🛇 1F6C7 | ⦸ 29B8 | 🙱 1F671 | 🙴 1F674 | 🙲 1F672 | 🙳 1F673 | ‽ 203D | 🙹 1F679 | 🙺 1F67A
6_ 96 | 🙻 1F67B | 🙦 1F666 | 🙤 1F664 | 🙥 1F665 | 🙧 1F667 | 🙚 1F65A | 🙘 1F658 | 🙙 1F659 | 🙛 1F65B | ⓪ 24EA | ① 2460 | ② 2461 | ③ 2462 | ④ 2463 | ⑤ 2464 | ⑥ 2465
7_ 112 | ⑦ 2466 | ⑧ 2467 | ⑨ 2468 | ⑩ 2469 | ⓿ 24FF | ❶ 2776 | ❷ 2777 | ❸ 2778 | ❹ 2779 | ❺ 277A | ❻ 277B | ❼ 277C | ❽ 277D | ❾ 277E | ❿ 277F |
8_ 128 | ☉ 2609 | 🌕︎ 1F315 | ☽ 263D | ☾ 263E | ⸿ 2E3F | ✝ 271D | 🕇 1F547 | 🕜︎ 1F55C | 🕝︎ 1F55D | 🕞︎ 1F55E | 🕟︎ 1F55F | 🕠︎ 1F560 | 🕡︎ 1F561 | 🕢︎ 1F562 | 🕣︎ 1F563 | 🕤︎ 1F564
9_ 144 | 🕥︎ 1F565 | 🕦︎ 1F566 | 🕧︎ 1F567 | 🙨 1F668 | 🙩 1F669 | ⋅ 22C5 | 🞄 1F784 | ⦁ 2981 | ● 25CF | ○ 25CB | 🞅 1F785 | 🞇 1F787 | 🞉 1F789 | ⊙ 2299 | ⦿ 29BF | 🞌 1F78C
A_ 160 | 🞍 1F78D | ◾︎ 25FE | ■ 25A0 | □ 25A1 | 🞑 1F791 | 🞒 1F792 | 🞓 1F793 | 🞔 1F794 | ▣ 25A3 | 🞕 1F795 | 🞖 1F796 | 🞗 1F797 | 🞘 1F798 | ⬩ 2B29 | ⬥ 2B25 | ◇ 25C7
B_ 176 | 🞚 1F79A | ◈ 25C8 | 🞛 1F79B | 🞜 1F79C | 🞝 1F79D | 🞞 1F79E | ⬪ 2B2A | ⬧ 2B27 | ◊ 25CA | 🞠 1F7A0 | ◖ 25D6 | ◗ 25D7 | ⯊ 2BCA | ⯋ 2BCB | ⯀ 2BC0 | ⯁ 2BC1
C_ 192 | ⬟ 2B1F | ⯂ 2BC2 | ⬣ 2B23 | ⬢ 2B22 | ⯃ 2BC3 | ⯄ 2BC4 | 🞡 1F7A1 | 🞢 1F7A2 | 🞣 1F7A3 | 🞤 1F7A4 | 🞥 1F7A5 | 🞦 1F7A6 | 🞧 1F7A7 | 🞨 1F7A8 | 🞩 1F7A9 | 🞪 1F7AA
D_ 208 | 🞫 1F7AB | 🞬 1F7AC | 🞭 1F7AD | 🞮 1F7AE | 🞯 1F7AF | 🞰 1F7B0 | 🞱 1F7B1 | 🞲 1F7B2 | 🞳 1F7B3 | 🞴 1F7B4 | 🞵 1F7B5 | 🞶 1F7B6 | 🞷 1F7B7 | 🞸 1F7B8 | 🞹 1F7B9 | 🞺 1F7BA
E_ 224 | 🞻 1F7BB | 🞼 1F7BC | 🞽 1F7BD | 🞾 1F7BE | 🞿 1F7BF | 🟀 1F7C0 | 🟂 1F7C2 | 🟄 1F7C4 | 🟆 1F7C6 | 🟉 1F7C9 | 🟊 1F7CA | ✶ 2736 | 🟌 1F7CC | 🟎 1F7CE | 🟐 1F7D0 | 🟒 1F7D2
F_ 240 | ✹ 2739 | 🟃 1F7C3 | 🟇 1F7C7 | ✯ 272F | 🟍 1F7CD | 🟔 1F7D4 | ⯌ 2BCC | ⯍ 2BCD | ※ 203B | ⁂ 2042 |  |  |  |  |  |

## Wingdings 3[edit]

Wingdings 3
Category | Symbol
Designer(s) | Charles Bigelow Kris Holmes
Foundry | Type Solutions
Sample

Wingdings 3 is a TrueType dingbat font distributed with Microsoft Office (up to version 2010) and some other Microsoft products.[5]

The font was originally developed in 1990 by Type Solutions, Inc. Currently,[when?] the copyright holder is Microsoft Corporation. Wingdings 3 consists almost entirely of arrow variations and includes many symbols for key tops as defined in ISO/IEC 9995-7.

Mosaic of Wingdings 3 characters

### Character set[edit]

Wingdings 3
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0_ 0 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
1_ 16 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
2_ 32 | SP 0020 | ⭠ 2B60 | ⭢ 2B62 | ⭡ 2B61 | ⭣ 2B63 | ⭦ 2B66 | ⭧ 2B67 | ⭩ 2B69 | ⭨ 2B68 | ⭰ 2B70 | ⭲ 2B72 | ⭱ 2B71 | ⭳ 2B73 | ⭶ 2B76 | ⭸ 2B78 | ⭻ 2B7B
3_ 48 | ⭽ 2B7D | ⭤ 2B64 | ⭥ 2B65 | ⭪ 2B6A | ⭬ 2B6C | ⭫ 2B6B | ⭭ 2B6D | ⭍ 2B4D | ⮠ 2BA0 | ⮡ 2BA1 | ⮢ 2BA2 | ⮣ 2BA3 | ⮤ 2BA4 | ⮥ 2BA5 | ⮦ 2BA6 | ⮧ 2BA7
4_ 64 | ⮐ 2B90 | ⮑ 2B91 | ⮒ 2B92 | ⮓ 2B93 | ⮀ 2B80 | ⮃ 2B83 | ⭾ 2B7E | ⭿ 2B7F | ⮄ 2B84 | ⮆ 2B86 | ⮅ 2B85 | ⮇ 2B87 | ⮏ 2B8F | ⮍ 2B8D | ⮎ 2B8E | ⮌ 2B8C
5_ 80 | ⭮ 2B6E | ⭯ 2B6F | ⎋ 238B | ⌤ 2324 | ⌃ 2303 | ⌥ 2325 | ␣ 2423 | ⍽ 237D | ⇪ 21EA | ⮸ 2BB8 | 🢠 1F8A0 | 🢡 1F8A1 | 🢢 1F8A2 | 🢣 1F8A3 | 🢤 1F8A4 | 🢥 1F8A5
6_ 96 | 🢦 1F8A6 | 🢧 1F8A7 | 🢨 1F8A8 | 🢩 1F8A9 | 🢪 1F8AA | 🢫 1F8AB | 🡐 1F850 | 🡒 1F852 | 🡑 1F851 | 🡓 1F853 | 🡔 1F854 | 🡕 1F855 | 🡗 1F857 | 🡖 1F856 | 🡘 1F858 | 🡙 1F859
7_ 112 | ▲ 25B2 | ▼ 25BC | △ 25B3 | ▽ 25BD | ◀ 25C0 | ▶ 25B6 | ◁ 25C1 | ▷ 25B7 | ◣ 25E3 | ◢ 25E2 | ◤ 25E4 | ◥ 25E5 | 🞀 1F780 | 🞂 1F782 | 🞁 1F781 |
8_ 128 | 🞃 1F783 | ⯅ 2BC5 | ⯆ 2BC6 | ⯇ 2BC7 | ⯈ 2BC8 | ⮜ 2B9C | ⮞ 2B9E | ⮝ 2B9D | ⮟ 2B9F | 🠐 1F810 | 🠒 1F812 | 🠑 1F811 | 🠓 1F813 | 🠔 1F814 | 🠖 1F816 | 🠕 1F815
9_ 144 | 🠗 1F817 | 🠘 1F818 | 🠚 1F81A | 🠙 1F819 | 🠛 1F81B | 🠜 1F81C | 🠞 1F81E | 🠝 1F81D | 🠟 1F81F | 🠀 1F800 | 🠂 1F802 | 🠁 1F801 | 🠃 1F803 | 🠄 1F804 | 🠆 1F806 | 🠅 1F805
A_ 160 | 🠇 1F807 | 🠈 1F808 | 🠊 1F80A | 🠉 1F809 | 🠋 1F80B | 🠠 1F820 | 🠢 1F822 | 🠤 1F824 | 🠦 1F826 | 🠨 1F828 | 🠪 1F82A | 🠬 1F82C | 🢜 1F89C | 🢝 1F89D | 🢞 1F89E | 🢟 1F89F
B_ 176 | 🠮 1F82E | 🠰 1F830 | 🠲 1F832 | 🠴 1F834 | 🠶 1F836 | 🠸 1F838 | 🠺 1F83A | 🠹 1F839 | 🠻 1F83B | 🢘 1F898 | 🢚 1F89A | 🢙 1F899 | 🢛 1F89B | 🠼 1F83C | 🠾 1F83E | 🠽 1F83D
C_ 192 | 🠿 1F83F | 🡀 1F840 | 🡂 1F842 | 🡁 1F841 | 🡃 1F843 | 🡄 1F844 | 🡆 1F846 | 🡅 1F845 | 🡇 1F847 | ⮨ 2BA8 | ⮩ 2BA9 | ⮪ 2BAA | ⮫ 2BAB | ⮬ 2BAC | ⮭ 2BAD | ⮮ 2BAE
D_ 208 | ⮯ 2BAF | 🡠 1F860 | 🡢 1F862 | 🡡 1F861 | 🡣 1F863 | 🡤 1F864 | 🡥 1F865 | 🡧 1F867 | 🡦 1F866 | 🡰 1F870 | 🡲 1F872 | 🡱 1F871 | 🡳 1F873 | 🡴 1F874 | 🡵 1F875 | 🡷 1F877
E_ 224 | 🡶 1F876 | 🢀 1F880 | 🢂 1F882 | 🢁 1F881 | 🢃 1F883 | 🢄 1F884 | 🢅 1F885 | 🢇 1F887 | 🢆 1F886 | 🢐 1F890 | 🢒 1F892 | 🢑 1F891 | 🢓 1F893 | 🢔 1F894 | 🢖 1F896 | 🢕 1F895
F_ 240 | 🢗 1F897 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |

## Controversy[edit]

The "NYC" symbols typed out in Wingdings

In 1992, only days after the release of Windows 3.1, it was discovered that the character sequence "NYC" (a frequently used abbreviation for New York City) in Wingdings was rendered as a skull and crossbones symbol, Star of David, and thumbs up gesture. This was often claimed to be an antisemitic message referencing New York's large Jewish community.[8] Microsoft strongly denied this was intentional, and insisted that the final arrangement of the glyphs in the font was largely random. (The character sequence "NYC" in the later-released Webdings font, in turn, was intentionally rendered as eye, heart, and city skyline, referring to the I Love New York logo.[9])

### 9/11 attacks[edit]

The "Q33 NY" symbols typed out in Wingdings

After September 11, 2001, an email was circulated claiming that entering "Q33 NY", which it claims is the flight number of the first plane to hit the Twin Towers, in Wingdings would bring up a character sequence of a plane flying into two rectangular paper sheet icons which may be interpreted as skyscrapers, followed by the skull and crossbones symbol and the Star of David (✈︎🗏︎🗏︎ ☠︎✡︎).[8] This is a hoax; the flight numbers of the two airplanes that hit the towers were American Airlines Flight 11 and United Airlines Flight 175; the tail numbers were N334AA and N612UA.[10]

## See also[edit]

- Dingbat
- Zapf Dingbats
- Webdings
- Unicode symbols
- Zodiac symbols
- Emoji

## References[edit]

1. ^ Notes on Lucida designs(by Charles Bigelow, November 2005)
2. ^ Unicode 7.0.0 Pictographic symbols (including many emoji), geometric symbols, arrows, and ornaments originating from the Wingdings and Webdings sets
3. ^ Wingdings and Webdings Symbols (Unicode document 11-052) by Michel Suignard, 2011-02-15, study of the repertoire and possibilities of unification
4. ^ a b Fonts supplied with Windows 3.1.
5. ^ a b c Wingdings font family
6. ^ Typeface - Google Patent Search
7. ^ United States Patent: D341848
8. ^ a b
   "Does Microsoft's Wingdings font includes hidden anti-Semitic and 9/11-referential messages?". snopes.com. 11 December 2005. Retrieved 23 October 2014.
9. ^ MS Denies Wingding Thing, Again|Wired Magazine
10. ^ Christensen, Brett M. (9 February 2017). "Q33 NY Wingdings Hoax – Elevens and the Wrath of the Eagle". Hoax-Slayer. Retrieved 27 August 2018.

Retrieved from "https://en.wikipedia.org/w/index.php?title=Wingdings&oldid=1047006285"
Categories:

- Symbol typefaces
- Typefaces and fonts introduced in 1990
- Windows XP typefaces
- Typefaces designed by Charles Bigelow (type designer)
- Typefaces designed by Kris Holmes

Hidden categories:

- Articles with short description
- Short description is different from Wikidata
- All articles with vague or ambiguous time
- Vague or ambiguous time from June 2014